Module tx Copy item path Source mode_info Nested message and enum types in ModeInfo. service_client Generated client implementations. AuthInfo AuthInfo describes the fee and signer modes that are used to sign a
transaction. BroadcastTxRequest BroadcastTxRequest is the request type for the Service.BroadcastTxRequest
RPC method. BroadcastTxResponse BroadcastTxResponse is the response type for the
Service.BroadcastTx method. Fee Fee includes the amount of coins paid in fees and the maximum
gas to be used by the transaction. The ratio yields an effective “gasprice”,
which must be above some miminum to be accepted into the mempool. GetBlockWithTxsRequest GetBlockWithTxsRequest is the request type for the Service.GetBlockWithTxs
RPC method. GetBlockWithTxsResponse GetBlockWithTxsResponse is the response type for the Service.GetBlockWithTxs method. GetTxRequest GetTxRequest is the request type for the Service.GetTx
RPC method. GetTxResponse GetTxResponse is the response type for the Service.GetTx method. GetTxsEventRequest GetTxsEventRequest is the request type for the Service.TxsByEvents
RPC method. GetTxsEventResponse GetTxsEventResponse is the response type for the Service.TxsByEvents
RPC method. ModeInfo ModeInfo describes the signing mode of a single or nested multisig signer. SignDoc SignDoc is the type used for generating sign bytes for SIGN_MODE_DIRECT. SignerInfo SignerInfo describes the public key and signing mode of a single top-level
signer. SimulateRequest SimulateRequest is the request type for the Service.Simulate
RPC method. SimulateResponse SimulateResponse is the response type for the
Service.SimulateRPC method. Tx Tx is the standard type used for broadcasting transactions. TxBody TxBody is the body of a transaction that all signers sign over. TxRaw TxRaw is a variant of Tx that pins the signer’s exact binary representation
of body and auth_info. This is used for signing, broadcasting and
verification. The binary serialize(tx: TxRaw) is stored in Tendermint and
the hash sha256(serialize(tx: TxRaw)) becomes the “txhash”, commonly used
as the transaction ID. BroadcastMode BroadcastMode specifies the broadcast mode for the TxService.Broadcast RPC method. OrderBy OrderBy defines the sorting order