pub struct SignerInfo {
pub public_key: Option<Any>,
pub mode_info: Option<ModeInfo>,
pub sequence: u64,
}Expand description
SignerInfo describes the public key and signing mode of a single top-level signer.
Fields
public_key: Option<Any>public_key is the public key of the signer. It is optional for accounts
that already exist in state. If unset, the verifier can use the required
signer address for this position and lookup the public key.
mode_info: Option<ModeInfo>mode_info describes the signing mode of the signer and is a nested structure to support nested multisig pubkey’s
sequence: u64sequence is the sequence of the account, which describes the number of committed transactions signed by a given address. It is used to prevent replay attacks.